Class: Java::JavaUtil::TreeSet
Instance Method Summary collapse
-
#first ⇒ Object
Fixes the jRuby #first to return nil on an empty set rather than raise a Java exception.
Fixes the jRuby #first to return nil on an empty set rather than raise a Java exception.