Method: ActiveSupport::CoreExtensions::String::Inflections#tableize
- Defined in:
- lib/caruby/active_support/core_ext/string/inflections.rb
#tableize ⇒ Object
Creates the name of a table like Rails does for models to table names. This method uses the pluralize method on the last word in the string.
"RawScaledScorer".tableize #=>"raw_scaled_scorers"
"egg_and_ham".tableize #=>"egg_and_hams"
"fancyCategory".tableize #=>"fancy_categories"
115 116 117 |
# File 'lib/caruby/active_support/core_ext/string/inflections.rb', line 115 def tableize Inflector.tableize(self) end |